package Shipment::UPS::WSDL::ShipTypes::FormType;
{
  $Shipment::UPS::WSDL::ShipTypes::FormType::VERSION = '0.11';
}
use strict;
use warnings;


__PACKAGE__->_set_element_form_qualified(1);

sub get_xmlns { 'http://www.ups.com/XMLSchema/XOLTWS/Ship/v1.0' };

our $XML_ATTRIBUTE_CLASS;
undef $XML_ATTRIBUTE_CLASS;

sub __get_attr_class {
    return $XML_ATTRIBUTE_CLASS;
}

use Class::Std::Fast::Storable constructor => 'none';
use base qw(SOAP::WSDL::XSD::Typelib::ComplexType);

Class::Std::initialize();

{ # BLOCK to scope variables

my %Code_of :ATTR(:get<Code>);
my %Description_of :ATTR(:get<Description>);
my %Image_of :ATTR(:get<Image>);
my %FormGroupId_of :ATTR(:get<FormGroupId>);
my %FormGroupIdName_of :ATTR(:get<FormGroupIdName>);

__PACKAGE__->_factory(
    [ qw(        Code
        Description
        Image
        FormGroupId
        FormGroupIdName

    ) ],
    {
        'Code' => \%Code_of,
        'Description' => \%Description_of,
        'Image' => \%Image_of,
        'FormGroupId' => \%FormGroupId_of,
        'FormGroupIdName' => \%FormGroupIdName_of,
    },
    {
        'Code' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        'Description' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        'Image' => 'Shipment::UPS::WSDL::ShipTypes::FormImageType',
        'FormGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
        'FormGroupIdName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
    },
    {

        'Code' => 'Code',
        'Description' => 'Description',
        'Image' => 'Image',
        'FormGroupId' => 'FormGroupId',
        'FormGroupIdName' => 'FormGroupIdName',
    }
);

} # end BLOCK







1;

__END__

=pod

=head1 NAME

Shipment::UPS::WSDL::ShipTypes::FormType

=head1 VERSION

version 0.11

=head1 DESCRIPTION

Perl data type class for the XML Schema defined complexType
FormType from the namespace http://www.ups.com/XMLSchema/XOLTWS/Ship/v1.0.

=head2 PROPERTIES

The following properties may be accessed using get_PROPERTY / set_PROPERTY
methods:

=over

=item * Code (min/maxOccurs: 1/1)

=item * Description (min/maxOccurs: 1/1)

=item * Image (min/maxOccurs: 0/1)

=item * FormGroupId (min/maxOccurs: 0/1)

=item * FormGroupIdName (min/maxOccurs: 0/1)

=back

=head1 NAME

Shipment::UPS::WSDL::ShipTypes::FormType

=head1 METHODS

=head2 new

Constructor. The following data structure may be passed to new():

 { # Shipment::UPS::WSDL::ShipTypes::FormType
   Code =>  $some_value, # string
   Description =>  $some_value, # string
   Image =>  { # Shipment::UPS::WSDL::ShipTypes::FormImageType
     ImageFormat =>  { # Shipment::UPS::WSDL::ShipTypes::ImageFormatType
       Code =>  $some_value, # string
       Description =>  $some_value, # string
     },
     GraphicImage =>  $some_value, # string
   },
   FormGroupId =>  $some_value, # string
   FormGroupIdName =>  $some_value, # string
 },

=head1 AUTHOR

Generated by SOAP::WSDL

=head1 AUTHOR

Andrew Baerg <baergaj@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Andrew Baerg.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
